@@ -1,10 +1,13 @@
+from __future__ import annotations
 from tuneflow_py.base_plugin import TuneflowPlugin, ReadAPIs
-from tuneflow_py.models.song import Song
-from tuneflow_py.models.track import TrackType, Track
+from tuneflow_py.models.automation import AutomationTarget, AutomationTargetType
 from tuneflow_py.models.clip import ClipType, Clip
 from tuneflow_py.models.note import Note
+from tuneflow_py.models.song import Song
+from tuneflow_py.models.tempo import TempoEvent
+from tuneflow_py.models.time_signature import TimeSignatureEvent
+from tuneflow_py.models.track import TrackType, Track
 from tuneflow_py.descriptors.widget import *
 from tuneflow_py.descriptors.text import *
 from tuneflow_py.descriptors.param import *
-from tuneflow_py.descriptors.song_access import *
-from tuneflow_py.descriptors.common import *
\ No newline at end of file
+from tuneflow_py.descriptors.common import *
